==> 0.0.3.tar.gz: lib/otp_page/otp_page.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:mini_app_likewallet/home/button_action/button_action.dart';
import 'package:mini_app_likewallet/library/address_service.dart';
import 'package:mini_app_likewallet/library/configuration_service.dart';
import 'package:mini_app_likewallet/library/crypto.dart';
import 'package:mini_app_likewallet/library/ethcontract.dart';
import 'package:mini_app_likewallet/lock_all/component/lock_all_component.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mini_app_likewallet/otp_page/component/otp_page_component.dart';
import 'package:mini_app_likewallet/provider/home_provider/home_provider.dart';
import 'package:mini_app_likewallet/provider/home_provider/loading_provider/loading_provider.dart';
import 'package:mini_app_likewallet/provider/home_provider/lock_all_provider/lock_all_provider.dart';
import 'package:mini_app_likewallet/provider/home_provider/otp_provider/otp_provider.dart';
import 'package:mini_app_likewallet/theme/loading.dart';
import 'package:mini_app_likewallet/theme/widget.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:web3dart/web3dart.dart';

class OTPPageScreen extends StatefulWidget {
  @override
  _OTPPageScreen createState() => _OTPPageScreen();
}

class _OTPPageScreen extends State<OTPPageScreen> {
  Widget buttonLock;
  OTPProvider _otpProvider;
  HomeProvider _homeProvider;
  LoadingProvider _loadingProvider;

  get w40 => SizedBox(width: 40.w);

  @override
  void didChangeDependencies() async {
    super.didChangeDependencies();
    _otpProvider = Provider.of<OTPProvider>(context);
    _homeProvider = Provider.of<HomeProvider>(context);
    _loadingProvider = Provider.of<LoadingProvider>(context);
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Container(
      width: 1080.0.w,
      height: 2119.0.h - 174.h,
      child: Stack(
        children: [
          Positioned(top: -174.h, child: OTPPageComponent.otpBackground()),
          context.watch<LoadingProvider>().getLoading
              ? Center(child: Loading.showLoading(context: context))
              : Container(
                  width: 1080.0.w,
                  height: 2119.0.h,
                  child: Column(
                    children: [
                      SizedBox(height: 148.h),
                      Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          OTPPageComponent.textDidGet(),
                          SizedBox(width: 18.w),
                          OTPPageComponent.buttonResend(context: context),
                        ],
                      ),
                      SizedBox(height: 226.h),
                      OTPPageComponent.textNumberPhone(
                          phone: _otpProvider.getNumberPhone),
                      SizedBox(height: 54.h),
                      OTPPageComponent.textOTP(),
                      SizedBox(height: 54.h),
                      numberOTP(),
                      SizedBox(height: 332.h),
                      WidgetTheme.numberPad(context: context),
                      WidgetTheme.bottomNumberPad(context: context),
                      Expanded(child: Container()),
                      closeButton(),
                      SizedBox(height: 43.h),
                    ],
                  ),
                ),
        ],
      ),
    );
  }

  Widget closeButton() {
    return InkWell(
      onTap: () {
        _homeProvider.setOTP(status: false);
      },
      child: ButtonAction.closeMenuWhite(),
    );
  }

  Widget numberOTP() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 0
                ? ''
                : _otpProvider.getTextOTP[0]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 1
                ? ''
                : _otpProvider.getTextOTP[1]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 2
                ? ''
                : _otpProvider.getTextOTP[2]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 3
                ? ''
                : _otpProvider.getTextOTP[3]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 4
                ? ''
                : _otpProvider.getTextOTP[4]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 5
                ? ''
                : _otpProvider.getTextOTP[5]),
      ],
    );
  }
}

==> 0.0.4.tar.gz: lib/otp_page/otp_page.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:minilikewallet/home/button_action/button_action.dart';
import 'package:minilikewallet/library/address_service.dart';
import 'package:minilikewallet/library/configuration_service.dart';
import 'package:minilikewallet/library/crypto.dart';
import 'package:minilikewallet/library/ethcontract.dart';
import 'package:minilikewallet/lock_all/component/lock_all_component.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:minilikewallet/otp_page/component/otp_page_component.dart';
import 'package:minilikewallet/provider/home_provider/home_provider.dart';
import 'package:minilikewallet/provider/home_provider/loading_provider/loading_provider.dart';
import 'package:minilikewallet/provider/home_provider/lock_all_provider/lock_all_provider.dart';
import 'package:minilikewallet/provider/home_provider/otp_provider/otp_provider.dart';
import 'package:minilikewallet/theme/loading.dart';
import 'package:minilikewallet/theme/widget.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:web3dart/web3dart.dart';

class OTPPageScreen extends StatefulWidget {
  OTPPageScreen({this.phone});
  final String phone;
  @override
  _OTPPageScreen createState() => _OTPPageScreen();
}

class _OTPPageScreen extends State<OTPPageScreen> {
  Widget buttonLock;
  OTPProvider _otpProvider;
  HomeProvider _homeProvider;
  LoadingProvider _loadingProvider;

  get w40 => SizedBox(width: 40.w);

  @override
  void didChangeDependencies() async {
    super.didChangeDependencies();
    _otpProvider = Provider.of<OTPProvider>(context);
    _homeProvider = Provider.of<HomeProvider>(context);
    _loadingProvider = Provider.of<LoadingProvider>(context);
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Container(
      width: 1080.0.w,
      height: 2119.0.h - 174.h,
      child: Stack(
        children: [
          Positioned(top: -174.h, child: OTPPageComponent.otpBackground()),
          _loadingProvider.getLoading
              ? Center(child: Loading.showLoading(context: context))
              : Container(
                  width: 1080.0.w,
                  height: 2119.0.h,
                  child: Column(
                    children: [
                      SizedBox(height: 148.h),
                      Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          OTPPageComponent.textDidGet(),
                          SizedBox(width: 18.w),
                          OTPPageComponent.buttonResend(
                              phone: widget.phone, context: context),
                        ],
                      ),
                      SizedBox(height: 226.h),
                      OTPPageComponent.textNumberPhone(
                          phone: _otpProvider.getNumberPhone),
                      SizedBox(height: 54.h),
                      OTPPageComponent.textOTP(),
                      SizedBox(height: 54.h),
                      numberOTP(),
                      SizedBox(height: 332.h),
                      WidgetTheme.numberPad(context: context),
                      WidgetTheme.bottomNumberPad(context: context),
                      Expanded(child: Container()),
                      closeButton(),
                      SizedBox(height: 43.h),
                    ],
                  ),
                ),
        ],
      ),
    );
  }

  Widget closeButton() {
    return InkWell(
      onTap: () {
        _homeProvider.setOTP(status: false);
      },
      child: ButtonAction.closeMenuWhite(),
    );
  }

  Widget numberOTP() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 0
                ? ''
                : _otpProvider.getTextOTP[0]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 1
                ? ''
                : _otpProvider.getTextOTP[1]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 2
                ? ''
                : _otpProvider.getTextOTP[2]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 3
                ? ''
                : _otpProvider.getTextOTP[3]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 4
                ? ''
                : _otpProvider.getTextOTP[4]),
        w40,
        OTPPageComponent.textInputOTP(
            numberOTP: _otpProvider.getTextOTP.length <= 5
                ? ''
                : _otpProvider.getTextOTP[5]),
      ],
    );
  }
}
